aboutsummaryrefslogtreecommitdiff
path: root/types
diff options
context:
space:
mode:
Diffstat (limited to 'types')
-rw-r--r--types/ext/dictionary.d.ts4
1 files changed, 2 insertions, 2 deletions
diff --git a/types/ext/dictionary.d.ts b/types/ext/dictionary.d.ts
index ca6a708a..cc53ec0a 100644
--- a/types/ext/dictionary.d.ts
+++ b/types/ext/dictionary.d.ts
@@ -232,9 +232,9 @@ export type TermDictionaryEntry = {
*/
sourceTermExactMatchCount: number;
/**
* The maximum length of the transformed text for all primary sources.
*/
- maxTransformedTextLength: number;
+ maxOriginalTextLength: number;
/**
* Headwords for the entry.
*/
@@ -232,9 +232,9 @@ export type TermDictionaryEntry = {
sourceTermExactMatchCount: number;
/**
- * The maximum length of the transformed text for all primary sources.
+ * The maximum length of the original text for all primary sources.
*/